@@ -1,4 +1,5 @@
 """Verify that the "all" reqs are in sync."""
+
 import sys
 
 from tomli import load
@@ -10,7 +11,7 @@ all_reqs = data["project"]["optional-dependencies"]["all"]
 remaining_all = all_reqs.copy()
 errors = []
 
-for (key, reqs) in data["project"]["optional-dependencies"].items():
+for key, reqs in data["project"]["optional-dependencies"].items():
     if key == "all":
         continue
     for req in reqs:
